@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2006 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -691,3 +691,27 @@ libnd_misc_get_tmpfile(const char *filename)
   return g_strdup(result);
 }
 
+
+lt_dlhandle
+libnd_misc_dlopen(const char *filename)
+{
+  lt_dlhandle hdl;
+#ifdef HAVE_LT_DLADVISE
+  lt_dladvise advise;
+
+  /* As of libltdl 2.2, we need to pass an explicit hint to the
+   * library that dlopened modules' symbols are to be made globally
+   * available. We use the advise mechanism to instruct libltdl to
+   * try various filename extensions and to make the symbols
+   * available.
+   */
+  lt_dladvise_init(&advise);
+  lt_dladvise_global(&advise);
+  lt_dladvise_ext(&advise);
+  hdl = lt_dlopenadvise(filename, advise);
+  lt_dladvise_destroy(&advise);
+#else
+  hdl = lt_dlopenext(filename);
+#endif
+  return hdl;
+}
