@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2006 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -378,11 +378,15 @@ packet_init(LND_Packet *packet, pcap_t * pcap)
    * present those in raw hex.
    */
   data_end = libnd_packet_get_end(packet);
-  
-  if ( (used_data_end =
-	proto->init_packet(packet, packet->data, data_end)) < data_end)
-    libnd_raw_proto_get()->init_packet(packet, used_data_end, data_end);
-  
+  used_data_end = proto->init_packet(packet, packet->data, data_end);
+
+  /* Here, we could also process data that are not actually used
+   * by the protocols contained in the packet.
+   *
+   *  if (used_data_end < data_end)
+   *     libnd_raw_proto_get()->init_packet(packet, used_data_end, data_end);
+   */
+
   /* Depending on our current filter configuration, mark this packet
    * as filtered or not. Only applicable if the packet belongs to trace,
    * as the trace defines the filtering configuration.
