@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2006 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -177,7 +177,7 @@ plugin_scan(const char *dir)
 static gboolean
 plugin_hook_up(LND_Plugin *plugin)
 {
-  lt_ptr_t     sym;
+  lt_ptr sym;
 
   if ((sym = lt_dlsym(plugin->lt, "name")) != NULL)
     plugin->name = sym;
@@ -245,11 +245,15 @@ plugin_load(void)
 	  
 	  D(("Trying %s\n", plugin->filename));
 	  
-	  if (! plugin->lt && ! (plugin->lt = lt_dlopenext(plugin->filename)))
+	  if (! plugin->lt)
 	    {
-	      D(("dlopen failed: %s\n", lt_dlerror()));
-	      failures++;
-	      continue;
+	      plugin->lt = libnd_misc_dlopen(plugin->filename);	      
+	      if (! plugin->lt)
+		{
+		  D(("dlopen failed on %s: %s\n", plugin->filename, lt_dlerror()));
+		  failures++;
+		  continue;
+		}
 	    }
 	  
 	  if (! plugin->initialized)
