@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2006 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -109,7 +109,7 @@ proto_plugin_new(char *filename)
   plugin->init        = proto_plugin_dummy_init;
   plugin->cleanup     = proto_plugin_dummy_op;
 
-  return (plugin);
+  return plugin;
 }
 
 
@@ -119,7 +119,8 @@ proto_plugin_free(LND_ProtoPlugin *plugin)
   if (!plugin)
     return;
 
-  lt_dlclose(plugin->lt);
+  if (plugin->lt)
+    lt_dlclose(plugin->lt);
   g_free(plugin->filename);
   g_free(plugin);
 }
@@ -129,9 +130,9 @@ static int
 proto_plugin_cmp(LND_ProtoPlugin *p1, char *filename)
 {
   if (!p1 || !filename)
-    return (-1);
+    return -1;
 
-  return (strcmp(p1->filename, filename));
+  return strcmp(p1->filename, filename);
 }
 
 
@@ -187,7 +188,7 @@ static gboolean
 proto_plugin_hook_up(LND_ProtoPlugin *plugin)
 {
   LND_Protocol *proto;
-  lt_ptr_t     sym;
+  lt_ptr sym;
 
   if ((sym = lt_dlsym(plugin->lt, "name")) != NULL)
     plugin->name = sym;
@@ -236,9 +237,8 @@ proto_plugin_load(void)
   for (l = g_list_first(proto_plugins); l; l = g_list_next(l))
     {
       plugin = (LND_ProtoPlugin *) l->data;
-
-      if (! (plugin->lt = lt_dlopenext(plugin->filename)) ||
-	  ! proto_plugin_hook_up(plugin))
+      plugin->lt = libnd_misc_dlopen(plugin->filename);
+      if (! plugin->lt  || ! proto_plugin_hook_up(plugin))
 	{
 	  l->data = NULL;
 	  proto_plugin_free(plugin);
@@ -284,6 +284,32 @@ libnd_proto_plugin_init(void)
   proto_plugin_load();
 }
 
+LND_ProtoPlugin *
+libnd_proto_plugin_add(LND_ProtoPluginInfoFunc name,
+		       LND_ProtoPluginInfoFunc description,
+		       LND_ProtoPluginInfoFunc author,
+		       LND_ProtoPluginInfoFunc version)
+{
+  LND_ProtoPlugin *plugin = proto_plugin_new("<internal>");
+  
+  if (!plugin)
+    return NULL;
+
+  if (name)
+    plugin->name = name;
+  if (description)
+    plugin->description = description;
+  if (author)
+    plugin->author = author;
+  if (version)
+    plugin->version = version;
+  
+  proto_plugins = g_list_append(proto_plugins, plugin);
+  proto_plugins = g_list_sort(proto_plugins, proto_plugin_strcmp);
+
+  return plugin;
+}
+
 
 const char   *
 libnd_proto_plugin_get_description(LND_ProtoPlugin *plugin)
