@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2006 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2010 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -56,6 +56,22 @@ static char *tokenpacket_tstamp = "01:23:45.678901 ";
 
 gint libnd_tcpdump_print_timestamp;
 
+/* PCAP internally uses different timeval and packet header types for
+ * savefile interaction. We need to duplicate them here so we send the
+ * right format to the tcpdump child processes, regardless of
+ * 32/64-bit operation.
+ */
+struct pcap_timeval {
+    bpf_int32 tv_sec;		/* seconds */
+    bpf_int32 tv_usec;		/* microseconds */
+};
+
+struct pcap_sf_pkthdr {
+    struct pcap_timeval ts;	/* time stamp */
+    bpf_u_int32 caplen;		/* length of portion present */
+    bpf_u_int32 len;		/* length this packet (off wire) */
+};
+
 /*
  * libnd_tcpdump_fill_in_options - creates a vector of options to pass to tcpdump.
  * @opt: string to paste parameters into
@@ -263,7 +279,7 @@ libnd_tcpdump_send_header(LND_Trace *trace)
   /* The parent process writes the pcap trace file header
      to the tcpdump child, as the beginning of the file:
   */
-  
+
   if (libnd_misc_writen(trace->tcpdump.fd, (guchar *) &(trace->tcpdump.pfh),
 		     sizeof(struct pcap_file_header))
       != sizeof(struct pcap_file_header))
@@ -316,7 +332,8 @@ tcpdump_send_packet(int td_fd,
 		    const struct pcap_pkthdr *hdr,
 		    const guchar *data)
 {
-  fd_set       fdset;
+  fd_set fdset;
+  struct pcap_sf_pkthdr sf_hdr;
 
   FD_ZERO(&fdset);
   FD_SET(td_fd, &fdset);
@@ -324,8 +341,14 @@ tcpdump_send_packet(int td_fd,
   if (select(td_fd + 1, NULL, &fdset, NULL, NULL) <= 0)
     goto error_exit;
 
-  /* printf("Sending packet: %u %u\n", hdr->len, hdr->caplen); */
-  if (write(td_fd, (guchar *) hdr, sizeof(struct pcap_pkthdr)) != sizeof(struct pcap_pkthdr))
+  /* Compare to pcap_dump in pcap's savefile.c. */
+
+  sf_hdr.ts.tv_sec  = hdr->ts.tv_sec;
+  sf_hdr.ts.tv_usec = hdr->ts.tv_usec;
+  sf_hdr.caplen     = hdr->caplen;
+  sf_hdr.len        = hdr->len;
+
+  if (write(td_fd, (guchar *) &sf_hdr, sizeof(sf_hdr)) != sizeof(sf_hdr))
     goto error_exit;
   
   if (write(td_fd, data, hdr->caplen) != (int) hdr->caplen)
