@@ -1,6 +1,6 @@
 /*
 
-Copyright (C) 2000 - 2007 Christian Kreibich <christian@whoop.org>.
+Copyright (C) 2000 - 2008 Christian Kreibich <christian@whoop.org>.
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -145,37 +145,37 @@ main(int argc, char **argv)
 	}
       else if (! strcmp(argv[i], "--prefix"))
 	{
-	  printf("/usr/local\n");
+	  printf("/home/christian/inst\n");
 	}
       else if (! strcmp(argv[i], "-v") ||
 	       ! strcmp(argv[i], "--version"))
 	{
-	  printf("0.10a\n");
+	  printf("0.12\n");
 	}
       else if (! strcmp(argv[i], "--cflags"))
 	{
 	  char *includes = "";
 
-	  if (strcmp("/usr/local/include", "/usr/include"))
-	    includes = "-I/usr/local/include ";
-	  printf("%s-I/usr/local/include/libnetdude/0.10a -I/usr/include/glib-1.2 -I/usr/lib/glib/include -I/n/banquet/db/kreibich/inst/include -I/n/banquet/db/kreibich/inst/include\n",
+	  if (strcmp("/home/christian/inst/include", "/usr/include"))
+	    includes = "-I/home/christian/inst/include ";
+	  printf("%s-I/home/christian/inst/include/libnetdude/0.12 -I/usr/include/glib-1.2 -I/usr/lib/glib/include -I/home/christian/inst/include -I/home/christian/inst/include\n",
 		 includes);
 	}
       else if (! strcmp(argv[i], "--libs"))
 	{
-	  printf("-L/usr/local/lib -L/usr/lib -lglib -L/n/banquet/db/kreibich/inst/lib -lpcapnav -lpcap -lnetdude\n");
+	  printf("-L/home/christian/inst/lib -L/usr/lib -lglib -L/home/christian/inst/lib -lpcapnav -lpcap -lnetdude\n");
 	}
       else if (! strcmp(argv[i], "--include-dir"))
 	{
-	  printf("/usr/local/include/libnetdude/0.10a\n");
+	  printf("/home/christian/inst/include/libnetdude/0.12\n");
 	}
       else if (! strcmp(argv[i], "--plugin-dir"))
 	{
-	  printf("/usr/local/share/libnetdude/0.10a/plugins\n");
+	  printf("/home/christian/inst/share/libnetdude/0.12/plugins\n");
 	}
       else if (! strcmp(argv[i], "--proto-dir"))
 	{
-	  printf("/usr/local/share/libnetdude/0.10a/protocols\n");
+	  printf("/home/christian/inst/share/libnetdude/0.12/protocols\n");
 	}
       else if (! strcmp(argv[i], "--plugins") ||
 	       ! strcmp(argv[i], "-p"))
